@@ -149,9 +149,18 @@ def create_split_tfrecords_from_csv(data_dir, csv_path, outfile1name, outfile2na
 	create_tfrecord_labeled(file1_addrs, file1_labels, outfile1name, IMAGE_SIZE)
 	create_tfrecord_labeled(file2_addrs, file2_labels, outfile2name, IMAGE_SIZE)
 
+def retrieve_file_paths(dirName):
+	filePaths = []
+	
+	for root, directories, files in os.walk(dirName):
+		for filename in files:
+			filePath = os.path.join(root, filename)
+			filePaths.append(filePath)
+			
+	return filePaths
 
 
-def create_split_tfrecords_data(data_dir, outfile1name, output1folder, outfile2name, output2folder, split_size_ratio,num_parts1 = 1, num_parts2 = 1,  IMAGE_SIZE = (192,192)):
+def create_split_tfrecords_data(data_dir, outfile1name, output1folder, outfile2name, output2folder, split_size_ratio,num_parts1 = 1, num_parts2 = 1,  IMAGE_SIZE = (192,192), zip = False):
 
 	print(f"Split ratio -> {split_size_ratio}")
 	addrs, labels = get_addrs_labels(data_dir)
@@ -172,6 +181,19 @@ def create_split_tfrecords_data(data_dir, outfile1name, output1folder, outfile2n
 	create_tfrecord_labeled(file2_addrs, file2_labels, outfile2name, IMAGE_SIZE, num_parts2)
 	os.chdir(Path(os.getcwd()).parent)
 	
+	if zip:
+		folder1_files = retrieve_file_paths(str(Path(output1folder).absolute()))
+		folder2_files = retrieve_file_paths(str(Path(output2folder).absolute()))
+		
+		import zipfile
+		
+		zip_file = zipfile.ZipFile('data' + '.zip', 'w')
+		with zip_file:
+			for file in train_files:
+				zip_file.write(file)
+			for file in val_files:
+				zip_file.write(file)
+	
 	print("Data Successfully created!")
 
 def affirmationfolder(func):
